@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,30 +16,39 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
+from google.protobuf import timestamp_pb2  # type: ignore
 
 from google.cloud.websecurityscanner_v1.services.web_security_scanner import pagers
-from google.cloud.websecurityscanner_v1.types import crawled_url
-from google.cloud.websecurityscanner_v1.types import finding
-from google.cloud.websecurityscanner_v1.types import finding_addon
-from google.cloud.websecurityscanner_v1.types import finding_type_stats
-from google.cloud.websecurityscanner_v1.types import scan_config
-from google.cloud.websecurityscanner_v1.types import scan_run
-from google.cloud.websecurityscanner_v1.types import scan_run_error_trace
-from google.cloud.websecurityscanner_v1.types import scan_run_warning_trace
-from google.cloud.websecurityscanner_v1.types import web_security_scanner
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import WebSecurityScannerTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
+from google.cloud.websecurityscanner_v1.types import (
+    crawled_url,
+    finding,
+    finding_addon,
+    finding_type_stats,
+    scan_config,
+    scan_run,
+    scan_run_error_trace,
+    scan_run_warning_trace,
+    web_security_scanner,
+)
+
 from .client import WebSecurityScannerClient
+from .transports.base import DEFAULT_CLIENT_INFO, WebSecurityScannerTransport
+from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
 
 
 class WebSecurityScannerAsyncClient:
@@ -114,6 +123,42 @@ class WebSecurityScannerAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return WebSecurityScannerClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> WebSecurityScannerTransport:
         """Returns the transport used by the client instance.
@@ -177,16 +222,34 @@ class WebSecurityScannerAsyncClient:
 
     async def create_scan_config(
         self,
-        request: web_security_scanner.CreateScanConfigRequest = None,
+        request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Creates a new ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_create_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.CreateScanConfigRequest(
+                )
+
+                # Make the request
+                response = await client.create_scan_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest, dict]):
                 The request object. Request for the `CreateScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -219,24 +282,44 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def delete_scan_config(
         self,
-        request: web_security_scanner.DeleteScanConfigRequest = None,
+        request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing ScanConfig and its child
         resources.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_delete_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.DeleteScanConfigRequest(
+                )
+
+                # Make the request
+                await client.delete_scan_config(request=request)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest, dict]):
                 The request object. Request for the `DeleteScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -274,21 +357,42 @@ class WebSecurityScannerAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def get_scan_config(
         self,
-        request: web_security_scanner.GetScanConfigRequest = None,
+        request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Gets a ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_get_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.GetScanConfigRequest(
+                )
+
+                # Make the request
+                response = await client.get_scan_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.GetScanConfigRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.GetScanConfigRequest, dict]):
                 The request object. Request for the `GetScanConfig`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -331,23 +435,47 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_scan_configs(
         self,
-        request: web_security_scanner.ListScanConfigsRequest = None,
+        request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanConfigsAsyncPager:
         r"""Lists ScanConfigs under a given project.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_list_scan_configs():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListScanConfigsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_scan_configs(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest, dict]):
                 The request object. Request for the `ListScanConfigs`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -392,12 +520,20 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListScanConfigsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -405,17 +541,35 @@ class WebSecurityScannerAsyncClient:
 
     async def update_scan_config(
         self,
-        request: web_security_scanner.UpdateScanConfigRequest = None,
+        request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Updates a ScanConfig. This method support partial
         update of a ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_update_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.UpdateScanConfigRequest(
+                )
+
+                # Make the request
+                response = await client.update_scan_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest, dict]):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -450,23 +604,46 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def start_scan_run(
         self,
-        request: web_security_scanner.StartScanRunRequest = None,
+        request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Start a ScanRun according to the given ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_start_scan_run():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.StartScanRunRequest(
+                )
+
+                # Make the request
+                response = await client.start_scan_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.StartScanRunRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.StartScanRunRequest, dict]):
                 The request object. Request for the `StartScanRun`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -500,23 +677,46 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def get_scan_run(
         self,
-        request: web_security_scanner.GetScanRunRequest = None,
+        request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Gets a ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_get_scan_run():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.GetScanRunRequest(
+                )
+
+                # Make the request
+                response = await client.get_scan_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.GetScanRunRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.GetScanRunRequest, dict]):
                 The request object. Request for the `GetScanRun` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -559,24 +759,48 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_scan_runs(
         self,
-        request: web_security_scanner.ListScanRunsRequest = None,
+        request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanRunsAsyncPager:
         r"""Lists ScanRuns under a given ScanConfig, in
         descending order of ScanRun stop time.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_list_scan_runs():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListScanRunsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_scan_runs(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.ListScanRunsRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListScanRunsRequest, dict]):
                 The request object. Request for the `ListScanRuns`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -621,12 +845,20 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListScanRunsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -634,16 +866,34 @@ class WebSecurityScannerAsyncClient:
 
     async def stop_scan_run(
         self,
-        request: web_security_scanner.StopScanRunRequest = None,
+        request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Stops a ScanRun. The stopped ScanRun is returned.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_stop_scan_run():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.StopScanRunRequest(
+                )
+
+                # Make the request
+                response = await client.stop_scan_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.StopScanRunRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.StopScanRunRequest, dict]):
                 The request object. Request for the `StopScanRun`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -677,23 +927,47 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_crawled_urls(
         self,
-        request: web_security_scanner.ListCrawledUrlsRequest = None,
+        request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCrawledUrlsAsyncPager:
         r"""List CrawledUrls under a given ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_list_crawled_urls():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListCrawledUrlsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_crawled_urls(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest, dict]):
                 The request object. Request for the `ListCrawledUrls`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -738,12 +1012,20 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListCrawledUrlsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -751,16 +1033,34 @@ class WebSecurityScannerAsyncClient:
 
     async def get_finding(
         self,
-        request: web_security_scanner.GetFindingRequest = None,
+        request: Union[web_security_scanner.GetFindingRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> finding.Finding:
         r"""Gets a Finding.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_get_finding():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.GetFindingRequest(
+                )
+
+                # Make the request
+                response = await client.get_finding(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.GetFindingRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.GetFindingRequest, dict]):
                 The request object. Request for the `GetFinding` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -803,23 +1103,47 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_findings(
         self,
-        request: web_security_scanner.ListFindingsRequest = None,
+        request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFindingsAsyncPager:
         r"""List Findings under a given ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_list_findings():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListFindingsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_findings(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.ListFindingsRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListFindingsRequest, dict]):
                 The request object. Request for the `ListFindings`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -864,12 +1188,20 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListFindingsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -877,16 +1209,34 @@ class WebSecurityScannerAsyncClient:
 
     async def list_finding_type_stats(
         self,
-        request: web_security_scanner.ListFindingTypeStatsRequest = None,
+        request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> web_security_scanner.ListFindingTypeStatsResponse:
         r"""List all FindingTypeStats under a given ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            async def sample_list_finding_type_stats():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerAsyncClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListFindingTypeStatsRequest(
+                )
+
+                # Make the request
+                response = await client.list_finding_type_stats(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest`):
+            request (Union[google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest, dict]):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -927,7 +1277,12 @@ class WebSecurityScannerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
