@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,11 @@
 #
 import proto  # type: ignore
 
-
 __protobuf__ = proto.module(
-    package="google.cloud.websecurityscanner.v1", manifest={"FindingTypeStats",},
+    package="google.cloud.websecurityscanner.v1",
+    manifest={
+        "FindingTypeStats",
+    },
 )
 
 
@@ -34,8 +36,14 @@ class FindingTypeStats(proto.Message):
             to this finding type.
     """
 
-    finding_type = proto.Field(proto.STRING, number=1,)
-    finding_count = proto.Field(proto.INT32, number=2,)
+    finding_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    finding_count = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
