@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,17 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.websecurityscanner_v1beta.types import (
     scan_config_error as gcw_scan_config_error,
 )
 
-
 __protobuf__ = proto.module(
-    package="google.cloud.websecurityscanner.v1beta", manifest={"ScanRunErrorTrace",},
+    package="google.cloud.websecurityscanner.v1beta",
+    manifest={
+        "ScanRunErrorTrace",
+    },
 )
 
 
@@ -59,13 +58,20 @@ class ScanRunErrorTrace(proto.Message):
         TOO_MANY_REDIRECTS = 5
         TOO_MANY_HTTP_ERRORS = 6
 
-    code = proto.Field(proto.ENUM, number=1, enum=Code,)
-
+    code = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Code,
+    )
     scan_config_error = proto.Field(
-        proto.MESSAGE, number=2, message=gcw_scan_config_error.ScanConfigError,
+        proto.MESSAGE,
+        number=2,
+        message=gcw_scan_config_error.ScanConfigError,
+    )
+    most_common_http_error_code = proto.Field(
+        proto.INT32,
+        number=3,
     )
-
-    most_common_http_error_code = proto.Field(proto.INT32, number=3)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
